# pylint: disable=no-member,wrong-import-position,too-many-lines,no-name-in-module
from typing import Callable, List

# app
import instill.protogen.app.app.v1alpha.app_pb2 as app_interface
import instill.protogen.app.app.v1alpha.app_public_service_pb2_grpc as app_service
import instill.protogen.app.app.v1alpha.conversation_pb2 as conversation_interface

# common
import instill.protogen.common.healthcheck.v1beta.healthcheck_pb2 as healthcheck
from instill.clients.base import Client, RequestFactory
from instill.clients.instance import InstillInstance
from instill.helpers.const import HOST_URL_PROD
from instill.utils.error_handler import grpc_handler


class AppClient(Client):
    def __init__(
        self,
        api_token: str,
        lookup_func: Callable[[str], str],
        url: str = HOST_URL_PROD,
        secure: bool = True,
        requester_id: str = "",
        async_enabled: bool = False,
    ) -> None:
        self.host: InstillInstance = InstillInstance(
            app_service.AppPublicServiceStub,
            url=url,
            token=api_token,
            secure=secure,
            async_enabled=async_enabled,
        )

        self.metadata = []
        self._lookup_uid = lookup_func

        if requester_id != "":
            requester_uid = lookup_func(requester_id)
            self.metadata = [("instill-requester-uid", requester_uid)]

    def close(self):
        if self.is_serving():
            self.host.channel.close()

    async def async_close(self):
        if self.is_serving():
            self.host.channel.close()

    @property
    def host(self):
        return self._host

    @host.setter
    def host(self, host: InstillInstance):
        self._host = host

    @property
    def metadata(self):
        return self._metadata

    @metadata.setter
    def metadata(self, metadata: List[tuple]):
        self._metadata = metadata

    def liveness(
        self,
        async_enabled: bool = False,
    ) -> app_interface.LivenessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Liveness,
                request=app_interface.LivenessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Liveness,
            request=app_interface.LivenessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def readiness(
        self,
        async_enabled: bool = False,
    ) -> app_interface.ReadinessResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Readiness,
                request=app_interface.ReadinessRequest(),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Readiness,
            request=app_interface.ReadinessRequest(),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    def is_serving(self) -> bool:
        try:
            return (
                self.readiness().health_check_response.status
                == healthcheck.HealthCheckResponse.SERVING_STATUS_SERVING
            )
        except Exception:
            return False

    @grpc_handler
    def create_app(
        self,
        namespace_id: str,
        app_id: str,
        description: str,
        tags: list[str],
        async_enabled: bool = False,
    ) -> app_interface.CreateAppResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateApp,
                request=app_interface.CreateAppRequest(
                    namespace_id=namespace_id,
                    id=app_id,
                    description=description,
                    tags=tags,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CreateApp,
            request=app_interface.CreateAppRequest(
                namespace_id=namespace_id,
                id=app_id,
                description=description,
                tags=tags,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_apps(
        self,
        namespace_id: str,
        async_enabled: bool = False,
    ) -> app_interface.ListAppsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListApps,
                request=app_interface.ListAppsRequest(
                    namespace_id=namespace_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListApps,
            request=app_interface.ListAppsRequest(
                namespace_id=namespace_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_app(
        self,
        namespace_id: str,
        app_id: str,
        new_app_id: str,
        new_description: str,
        new_tags: list[str],
        last_ai_assistant_app_catalog_uid: str,
        last_ai_assistant_app_top_k: int,
        async_enabled: bool = False,
    ) -> app_interface.UpdateAppResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateApp,
                request=app_interface.UpdateAppRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    new_app_id=new_app_id,
                    new_description=new_description,
                    new_tags=new_tags,
                    last_ai_assistant_app_catalog_uid=last_ai_assistant_app_catalog_uid,
                    last_ai_assistant_app_top_k=last_ai_assistant_app_top_k,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UpdateApp,
            request=app_interface.UpdateAppRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                new_app_id=new_app_id,
                new_description=new_description,
                new_tags=new_tags,
                last_ai_assistant_app_catalog_uid=last_ai_assistant_app_catalog_uid,
                last_ai_assistant_app_top_k=last_ai_assistant_app_top_k,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_app(
        self,
        namespace_id: str,
        app_id: str,
        async_enabled: bool = False,
    ) -> app_interface.DeleteAppResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteApp,
                request=app_interface.DeleteAppRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteApp,
            request=app_interface.DeleteAppRequest(
                namespace_id=namespace_id,
                app_id=app_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def create_conversation(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        async_enabled: bool = False,
    ) -> conversation_interface.CreateConversationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateConversation,
                request=conversation_interface.CreateConversationRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CreateConversation,
            request=conversation_interface.CreateConversationRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_conversations(
        self,
        namespace_id: str,
        app_id: str,
        conversation_uid: str,
        conversation_id: str,
        page_size: int = 10,
        page_token: str = "",
        if_all: bool = False,
        async_enabled: bool = False,
    ) -> conversation_interface.ListConversationsResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListConversations,
                request=conversation_interface.ListConversationsRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_uid=conversation_uid,
                    conversation_id=conversation_id,
                    page_size=page_size,
                    page_token=page_token,
                    if_all=if_all,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListConversations,
            request=conversation_interface.ListConversationsRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_uid=conversation_uid,
                conversation_id=conversation_id,
                page_size=page_size,
                page_token=page_token,
                if_all=if_all,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_conversation(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        new_conversation_id: str,
        last_used_catalog_uid: str,
        last_used_top_k: int,
        async_enabled: bool = False,
    ) -> conversation_interface.UpdateConversationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateConversation,
                request=conversation_interface.UpdateConversationRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                    new_conversation_id=new_conversation_id,
                    last_used_catalog_uid=last_used_catalog_uid,
                    last_used_top_k=last_used_top_k,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UpdateConversation,
            request=conversation_interface.UpdateConversationRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
                new_conversation_id=new_conversation_id,
                last_used_catalog_uid=last_used_catalog_uid,
                last_used_top_k=last_used_top_k,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_conversation(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        async_enabled: bool = False,
    ) -> conversation_interface.DeleteConversationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteConversation,
                request=conversation_interface.DeleteConversationRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteConversation,
            request=conversation_interface.DeleteConversationRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def create_message(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        content: str,
        role: str,
        async_enabled: bool = False,
    ) -> conversation_interface.CreateMessageResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.CreateMessage,
                request=conversation_interface.CreateMessageRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                    content=content,
                    role=role,
                    type=conversation_interface.Message.MessageType.MESSAGE_TYPE_TEXT,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.CreateMessage,
            request=conversation_interface.CreateMessageRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
                content=content,
                role=role,
                type=conversation_interface.Message.MessageType.MESSAGE_TYPE_TEXT,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def list_messages(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        latest_k: int,
        include_system_messages: bool,
        message_uid: str,
        page_size: int = 10,
        page_token: str = "",
        if_all: bool = False,
        async_enabled: bool = False,
    ) -> conversation_interface.ListMessagesResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.ListMessages,
                request=conversation_interface.ListMessagesRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                    latest_k=latest_k,
                    include_system_messages=include_system_messages,
                    message_uid=message_uid,
                    page_size=page_size,
                    page_token=page_token,
                    if_all=if_all,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.ListMessages,
            request=conversation_interface.ListMessagesRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
                latest_k=latest_k,
                include_system_messages=include_system_messages,
                message_uid=message_uid,
                page_size=page_size,
                page_token=page_token,
                if_all=if_all,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def update_message(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        message_uid: str,
        content: str,
        async_enabled: bool = False,
    ) -> conversation_interface.UpdateMessageResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.UpdateMessage,
                request=conversation_interface.UpdateMessageRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                    message_uid=message_uid,
                    content=content,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.UpdateMessage,
            request=conversation_interface.UpdateMessageRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
                message_uid=message_uid,
                content=content,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def delete_message(
        self,
        namespace_id: str,
        app_id: str,
        conversation_id: str,
        message_uid: str,
        async_enabled: bool = False,
    ) -> conversation_interface.DeleteMessageResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.DeleteMessage,
                request=conversation_interface.DeleteMessageRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    conversation_id=conversation_id,
                    message_uid=message_uid,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.DeleteMessage,
            request=conversation_interface.DeleteMessageRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                conversation_id=conversation_id,
                message_uid=message_uid,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def get_playground_conversation(
        self,
        namespace_id: str,
        app_id: str,
        async_enabled: bool = False,
    ) -> app_interface.GetPlaygroundConversationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.GetPlaygroundConversation,
                request=app_interface.GetPlaygroundConversationRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.GetPlaygroundConversation,
            request=app_interface.GetPlaygroundConversationRequest(
                namespace_id=namespace_id,
                app_id=app_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def restart_playground_conversation(
        self,
        namespace_id: str,
        app_id: str,
        async_enabled: bool = False,
    ) -> app_interface.RestartPlaygroundConversationResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.RestartPlaygroundConversation,
                request=app_interface.RestartPlaygroundConversationRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.RestartPlaygroundConversation,
            request=app_interface.RestartPlaygroundConversationRequest(
                namespace_id=namespace_id,
                app_id=app_id,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()

    @grpc_handler
    def chat(
        self,
        namespace_id: str,
        app_id: str,
        catalog_id: str,
        conversation_uid: str,
        message: str,
        top_k: int,
        async_enabled: bool = False,
    ) -> conversation_interface.ChatResponse:
        if async_enabled:
            return RequestFactory(
                method=self.host.async_client.Chat,
                request=conversation_interface.ChatRequest(
                    namespace_id=namespace_id,
                    app_id=app_id,
                    catalog_id=catalog_id,
                    conversation_uid=conversation_uid,
                    message=message,
                    top_k=top_k,
                ),
                metadata=self.host.metadata + self.metadata,
            ).send_async()

        return RequestFactory(
            method=self.host.client.Chat,
            request=conversation_interface.ChatRequest(
                namespace_id=namespace_id,
                app_id=app_id,
                catalog_id=catalog_id,
                conversation_uid=conversation_uid,
                message=message,
                top_k=top_k,
            ),
            metadata=self.host.metadata + self.metadata,
        ).send_sync()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ReportPipelineTriggerRequest(google.protobuf.message.Message):
    """Pipeline trigger records REQ and RES messages for `pipeline-backend` clients

    ReportPipelineTriggerRequest represents a request for reporting a
    pipeline-trigger record
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    USAGE_RECORD_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def pipeline(self) -> global___PipelineData:
        """Pipeline information"""
    @property
    def usage_record(self) -> global___PipelineUsageRecord:
        """Pipeline trigger record"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        pipeline: global___PipelineData | None = ...,
        usage_record: global___PipelineUsageRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "usage_record", b"usage_record", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "usage_record", b"usage_record", "user", b"user"]) -> None: ...

global___ReportPipelineTriggerRequest = ReportPipelineTriggerRequest

@typing_extensions.final
class ReportPipelineTriggerResponse(google.protobuf.message.Message):
    """ReportPipelineTriggerResponse represents a respond to a
    pipeline-trigger-record report request
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NULL_FIELD_NUMBER: builtins.int
    @property
    def null(self) -> global___NullMessage:
        """Null message for empty response"""
    def __init__(
        self,
        *,
        null: global___NullMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["null", b"null"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["null", b"null"]) -> None: ...

global___ReportPipelineTriggerResponse = ReportPipelineTriggerResponse

@typing_extensions.final
class ReportPipelineTriggersRequest(google.protobuf.message.Message):
    """ReportPipelineTriggersRequest represents a request for reporting a list of
    pipeline-trigger records in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_TRIGGER_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def pipeline_trigger_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReportPipelineTriggerRequest]:
        """A list of pipeline trigger requests"""
    def __init__(
        self,
        *,
        pipeline_trigger_records: collections.abc.Iterable[global___ReportPipelineTriggerRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline_trigger_records", b"pipeline_trigger_records"]) -> None: ...

global___ReportPipelineTriggersRequest = ReportPipelineTriggersRequest

@typing_extensions.final
class ReportPipelineTriggersResponse(google.protobuf.message.Message):
    """ReportPipelineTriggersResponse represents a respond to a
    pipeline-trigger-records reporting bulk request
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NULL_FIELD_NUMBER: builtins.int
    @property
    def null(self) -> global___NullMessage:
        """Null message for empty response"""
    def __init__(
        self,
        *,
        null: global___NullMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["null", b"null"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["null", b"null"]) -> None: ...

global___ReportPipelineTriggersResponse = ReportPipelineTriggersResponse

@typing_extensions.final
class ReportModelOnlineRequest(google.protobuf.message.Message):
    """Model online records REQ and RES messages for `model-backend` clients

    ReportModelOnlineRequest represents a request for reporting a model-online
    record
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    CUM_USAGE_RECORD_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def model(self) -> global___ModelData:
        """Model information"""
    @property
    def cum_usage_record(self) -> global___ModelUsageRecord:
        """Model online record"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        model: global___ModelData | None = ...,
        cum_usage_record: global___ModelUsageRecord | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cum_usage_record", b"cum_usage_record", "model", b"model", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cum_usage_record", b"cum_usage_record", "model", b"model", "user", b"user"]) -> None: ...

global___ReportModelOnlineRequest = ReportModelOnlineRequest

@typing_extensions.final
class ReportModelOnlineResponse(google.protobuf.message.Message):
    """ReportModelOnlineResponse represents a respond to a model-online-record
    report request
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NULL_FIELD_NUMBER: builtins.int
    @property
    def null(self) -> global___NullMessage:
        """Null message for empty response"""
    def __init__(
        self,
        *,
        null: global___NullMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["null", b"null"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["null", b"null"]) -> None: ...

global___ReportModelOnlineResponse = ReportModelOnlineResponse

@typing_extensions.final
class ReportModelOnlinesRequest(google.protobuf.message.Message):
    """ReportModelOnlinesRequest represents a request for reporting a list of
    model-online records in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODEL_ONLINE_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def model_online_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReportModelOnlineRequest]:
        """A list of model online requests"""
    def __init__(
        self,
        *,
        model_online_records: collections.abc.Iterable[global___ReportModelOnlineRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["model_online_records", b"model_online_records"]) -> None: ...

global___ReportModelOnlinesRequest = ReportModelOnlinesRequest

@typing_extensions.final
class ReportModelOnlinesResponse(google.protobuf.message.Message):
    """ReportModelOnlinesResponse represents a respond to a model-online-records
    reporting bulk request
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NULL_FIELD_NUMBER: builtins.int
    @property
    def null(self) -> global___NullMessage:
        """Null message for empty response"""
    def __init__(
        self,
        *,
        null: global___NullMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["null", b"null"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["null", b"null"]) -> None: ...

global___ReportModelOnlinesResponse = ReportModelOnlinesResponse

@typing_extensions.final
class GetPipelinesRequest(google.protobuf.message.Message):
    """Query pipeline info with user info

    GetPipelinesRequest represents a request for the pipelines recorded given a
    user and time interval
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetPipelinesRequest = GetPipelinesRequest

@typing_extensions.final
class GetPipelinesResponse(google.protobuf.message.Message):
    """GetPipelinesResponse represents a respond to GetPipelineRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINES_FIELD_NUMBER: builtins.int
    @property
    def pipelines(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineData]:
        """A list of pipeline informations"""
    def __init__(
        self,
        *,
        pipelines: collections.abc.Iterable[global___PipelineData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipelines", b"pipelines"]) -> None: ...

global___GetPipelinesResponse = GetPipelinesResponse

@typing_extensions.final
class GetModelsRequest(google.protobuf.message.Message):
    """Query model info with user info

    GetModelsRequest represents a request for the models recorded given user and
    time interval
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetModelsRequest = GetModelsRequest

@typing_extensions.final
class GetModelsResponse(google.protobuf.message.Message):
    """GetPipelinesResponse represents a respond to GetModelsRequest"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MODELS_FIELD_NUMBER: builtins.int
    @property
    def models(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelData]:
        """A list of model informations"""
    def __init__(
        self,
        *,
        models: collections.abc.Iterable[global___ModelData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["models", b"models"]) -> None: ...

global___GetModelsResponse = GetModelsResponse

@typing_extensions.final
class GetPipelineTriggerRecordsRequest(google.protobuf.message.Message):
    """Query REQ and RES for pipeline trigger records and summary

    GetPipelineTriggerRecordsRequest represents a query for pipeline trigger
    records
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def pipeline(self) -> global___PipelineData:
        """Pipeline information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        pipeline: global___PipelineData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetPipelineTriggerRecordsRequest = GetPipelineTriggerRecordsRequest

@typing_extensions.final
class GetPipelineTriggerRecordsResponse(google.protobuf.message.Message):
    """GetPipelineTriggerRecordsResponse represents a response to
    GetPipelineTriggerRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORDS_FIELD_NUMBER: builtins.int
    @property
    def records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineUsageRecord]:
        """A list of pipeline trigger records"""
    def __init__(
        self,
        *,
        records: collections.abc.Iterable[global___PipelineUsageRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["records", b"records"]) -> None: ...

global___GetPipelineTriggerRecordsResponse = GetPipelineTriggerRecordsResponse

@typing_extensions.final
class GetBulkPipelineTriggerRecordsRequest(google.protobuf.message.Message):
    """GetBulkPipelineTriggerRecordsRequest represents a query for pipeline trigger
    records in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetPipelineTriggerRecordsRequest]:
        """A list of pipeline trigger record request payloads"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetPipelineTriggerRecordsRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkPipelineTriggerRecordsRequest = GetBulkPipelineTriggerRecordsRequest

@typing_extensions.final
class GetBulkPipelineTriggerRecordsResponse(google.protobuf.message.Message):
    """GetBulkPipelineTriggerRecordsResponse represents a response to
    GetBulkPipelineTriggerRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def bulk_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetPipelineTriggerRecordsResponse]:
        """A list of pipeline trigger record lists"""
    def __init__(
        self,
        *,
        bulk_records: collections.abc.Iterable[global___GetPipelineTriggerRecordsResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_records", b"bulk_records"]) -> None: ...

global___GetBulkPipelineTriggerRecordsResponse = GetBulkPipelineTriggerRecordsResponse

@typing_extensions.final
class GetCumulativePipelineTriggerRecordsRequest(google.protobuf.message.Message):
    """GetCumulativePipelineTriggerRecordsRequest represents a query for cumulative
    pipeline trigger records
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def pipeline(self) -> global___PipelineData:
        """Pipeline information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        pipeline: global___PipelineData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetCumulativePipelineTriggerRecordsRequest = GetCumulativePipelineTriggerRecordsRequest

@typing_extensions.final
class GetCumulativePipelineTriggerRecordsResponse(google.protobuf.message.Message):
    """GetCumulativePipelineTriggerRecordsResponse represents a response to
    GetCumulativePipelineTriggerRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUMULATIVE_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def cumulative_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PipelineUsageRecord]:
        """Pipeline trigger records where values are in cumulative formats"""
    def __init__(
        self,
        *,
        cumulative_records: collections.abc.Iterable[global___PipelineUsageRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cumulative_records", b"cumulative_records"]) -> None: ...

global___GetCumulativePipelineTriggerRecordsResponse = GetCumulativePipelineTriggerRecordsResponse

@typing_extensions.final
class GetBulkCumulativePipelineTriggerRecordsRequest(google.protobuf.message.Message):
    """GetBulkCumulativePipelineTriggerRecordsRequest represents a query for
    cumulative pipeline trigger records in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetCumulativePipelineTriggerRecordsRequest]:
        """A list of cumulative pipeline trigger record request payloads"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetCumulativePipelineTriggerRecordsRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkCumulativePipelineTriggerRecordsRequest = GetBulkCumulativePipelineTriggerRecordsRequest

@typing_extensions.final
class GetBulkCumulativePipelineTriggerRecordsResponse(google.protobuf.message.Message):
    """GetBulkCumulativePipelineTriggerRecordsResponse represents a response to
    GetBulkCumulativePipelineTriggerRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_CUMULATIVE_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def bulk_cumulative_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetCumulativePipelineTriggerRecordsResponse]:
        """A list of cumulative pipeline trigger record lists"""
    def __init__(
        self,
        *,
        bulk_cumulative_records: collections.abc.Iterable[global___GetCumulativePipelineTriggerRecordsResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_cumulative_records", b"bulk_cumulative_records"]) -> None: ...

global___GetBulkCumulativePipelineTriggerRecordsResponse = GetBulkCumulativePipelineTriggerRecordsResponse

@typing_extensions.final
class GetPipelineTriggerSummaryRequest(google.protobuf.message.Message):
    """GetPipelineTriggerSummaryRequest represents a query for pipeline trigger
    summary
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def pipeline(self) -> global___PipelineData:
        """Pipeline information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        pipeline: global___PipelineData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetPipelineTriggerSummaryRequest = GetPipelineTriggerSummaryRequest

@typing_extensions.final
class GetPipelineTriggerSummaryResponse(google.protobuf.message.Message):
    """GetPipelineTriggerSummaryResponse represents a response to
    GetPipelineTriggerSummaryRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def summaries(self) -> global___UsageSummary:
        """The total pipeline trigger usage in the time interval"""
    def __init__(
        self,
        *,
        summaries: global___UsageSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summaries", b"summaries"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["summaries", b"summaries"]) -> None: ...

global___GetPipelineTriggerSummaryResponse = GetPipelineTriggerSummaryResponse

@typing_extensions.final
class GetBulkPipelineTriggerSummariesRequest(google.protobuf.message.Message):
    """GetBulkPipelineTriggerSummariesRequest represents a query for pipeline
    trigger summaries in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetPipelineTriggerSummaryRequest]:
        """A list of queries for pipeline trigger summaries"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetPipelineTriggerSummaryRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkPipelineTriggerSummariesRequest = GetBulkPipelineTriggerSummariesRequest

@typing_extensions.final
class GetBulkPipelineTriggerSummariesResponse(google.protobuf.message.Message):
    """GetBulkPipelineTriggerSummariesResponse represents a response to
    GetBulkPipelineTriggerSummariesRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetPipelineTriggerSummaryResponse]:
        """A list of pipeline trigger usage summaries"""
    def __init__(
        self,
        *,
        bulk_summaries: collections.abc.Iterable[global___GetPipelineTriggerSummaryResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_summaries", b"bulk_summaries"]) -> None: ...

global___GetBulkPipelineTriggerSummariesResponse = GetBulkPipelineTriggerSummariesResponse

@typing_extensions.final
class GetModelOnlineRecordsRequest(google.protobuf.message.Message):
    """Query REQ and RES for model online records and summary

    GetModelOnlineRecordsRequest represent a query for model online records
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def model(self) -> global___ModelData:
        """Model information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        model: global___ModelData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetModelOnlineRecordsRequest = GetModelOnlineRecordsRequest

@typing_extensions.final
class GetModelOnlineRecordsResponse(google.protobuf.message.Message):
    """GetModelOnlineRecordsResponse represents a response to
    GetModelOnlineRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECORDS_FIELD_NUMBER: builtins.int
    @property
    def records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelUsageRecord]:
        """A list of model trigger records"""
    def __init__(
        self,
        *,
        records: collections.abc.Iterable[global___ModelUsageRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["records", b"records"]) -> None: ...

global___GetModelOnlineRecordsResponse = GetModelOnlineRecordsResponse

@typing_extensions.final
class GetBulkModelOnlineRecordsRequest(google.protobuf.message.Message):
    """GetBulkModelOnlineRecordsRequest represents a query for model online records
    in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetModelOnlineRecordsRequest]:
        """A list of model online records request payloads"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetModelOnlineRecordsRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkModelOnlineRecordsRequest = GetBulkModelOnlineRecordsRequest

@typing_extensions.final
class GetBulkModelOnlineRecordsResponse(google.protobuf.message.Message):
    """GetBulkModelOnlineRecordsResponse represents a response to
    GetBulkModelOnlineRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def bulk_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetModelOnlineRecordsResponse]:
        """A list of model online record lists"""
    def __init__(
        self,
        *,
        bulk_records: collections.abc.Iterable[global___GetModelOnlineRecordsResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_records", b"bulk_records"]) -> None: ...

global___GetBulkModelOnlineRecordsResponse = GetBulkModelOnlineRecordsResponse

@typing_extensions.final
class GetCumulativeModelOnlineRecordsRequest(google.protobuf.message.Message):
    """GetCumulativeModelOnlineRecordsRequest represents a query for cumulative
    model online records
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def model(self) -> global___ModelData:
        """Model information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        model: global___ModelData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetCumulativeModelOnlineRecordsRequest = GetCumulativeModelOnlineRecordsRequest

@typing_extensions.final
class GetCumulativeModelOnlineRecordsResponse(google.protobuf.message.Message):
    """GetCumulativeModelOnlineRecordsResponse represents a response to
    GetCumulativeModelOnlineRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CUMULATIVE_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def cumulative_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ModelUsageRecord]:
        """A list of model online records in cumulative format"""
    def __init__(
        self,
        *,
        cumulative_records: collections.abc.Iterable[global___ModelUsageRecord] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cumulative_records", b"cumulative_records"]) -> None: ...

global___GetCumulativeModelOnlineRecordsResponse = GetCumulativeModelOnlineRecordsResponse

@typing_extensions.final
class GetBulkCumulativeModelOnlineRecordsRequest(google.protobuf.message.Message):
    """GetBulkCumulativeModelOnlineRecordsRequest represents a query for cumulative
    model online records in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetCumulativeModelOnlineRecordsRequest]:
        """A list of cumulative model online record request payloads"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetCumulativeModelOnlineRecordsRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkCumulativeModelOnlineRecordsRequest = GetBulkCumulativeModelOnlineRecordsRequest

@typing_extensions.final
class GetBulkCumulativeModelOnlineRecordsResponse(google.protobuf.message.Message):
    """GetBulkCumulativeModelOnlineRecordsResponse represents a response to
    GetBulkCumulativeModelOnlineRecordsRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_CUMULATIVE_RECORDS_FIELD_NUMBER: builtins.int
    @property
    def bulk_cumulative_records(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetCumulativeModelOnlineRecordsResponse]:
        """A list of cumulative model online record lists"""
    def __init__(
        self,
        *,
        bulk_cumulative_records: collections.abc.Iterable[global___GetCumulativeModelOnlineRecordsResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_cumulative_records", b"bulk_cumulative_records"]) -> None: ...

global___GetBulkCumulativeModelOnlineRecordsResponse = GetBulkCumulativeModelOnlineRecordsResponse

@typing_extensions.final
class GetModelOnlineSummaryRequest(google.protobuf.message.Message):
    """GetModelOnlineSummaryRequest represents a query for model online summary"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def model(self) -> global___ModelData:
        """Pipeline information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        model: global___ModelData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetModelOnlineSummaryRequest = GetModelOnlineSummaryRequest

@typing_extensions.final
class GetModelOnlineSummaryResponse(google.protobuf.message.Message):
    """GetModelOnlineSummaryResponse represents a response to
    GetModelOnlineSummaryRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUMMARY_FIELD_NUMBER: builtins.int
    @property
    def summary(self) -> global___UsageSummary:
        """The total model online usage in the time interval"""
    def __init__(
        self,
        *,
        summary: global___UsageSummary | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["summary", b"summary"]) -> None: ...

global___GetModelOnlineSummaryResponse = GetModelOnlineSummaryResponse

@typing_extensions.final
class GetBulkModelOnlineSummaryRequest(google.protobuf.message.Message):
    """GetBulkModelOnlineSummaryRequest represents a query for model online
    summaries in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetModelOnlineSummaryRequest]:
        """A list of queries for model online summaries"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetModelOnlineSummaryRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkModelOnlineSummaryRequest = GetBulkModelOnlineSummaryRequest

@typing_extensions.final
class GetBulkModelOnlineSummaryResponse(google.protobuf.message.Message):
    """GetBulkModelOnlineSummaryResponse represents a response to
    GetBulkModelOnlineSummaryRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_SUMMARIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_summaries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetModelOnlineSummaryResponse]:
        """A list of model online usage summaries"""
    def __init__(
        self,
        *,
        bulk_summaries: collections.abc.Iterable[global___GetModelOnlineSummaryResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_summaries", b"bulk_summaries"]) -> None: ...

global___GetBulkModelOnlineSummaryResponse = GetBulkModelOnlineSummaryResponse

@typing_extensions.final
class GetPipelineTriggerPriceRequest(google.protobuf.message.Message):
    """We only provide the price that will be charged for the current period

    GetPipelineTriggerPriceRequest represents a query for pipeline trigger prices
    given the billing periods covered by the time interval
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    PIPELINE_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def pipeline(self) -> global___PipelineData:
        """Pipeline information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        pipeline: global___PipelineData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pipeline", b"pipeline", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetPipelineTriggerPriceRequest = GetPipelineTriggerPriceRequest

@typing_extensions.final
class GetPipelineTriggerPriceResponse(google.protobuf.message.Message):
    """GetPipelineTriggerPriceResponse represents a response to
    GetPipelineTriggerPriceRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRICE_FIELD_NUMBER: builtins.int
    @property
    def price(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PriceData]:
        """A list of pipeline trigger prices given the billing periods covered by the
        time interval
        """
    def __init__(
        self,
        *,
        price: collections.abc.Iterable[global___PriceData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["price", b"price"]) -> None: ...

global___GetPipelineTriggerPriceResponse = GetPipelineTriggerPriceResponse

@typing_extensions.final
class GetBulkPipelineTriggerPriceRequest(google.protobuf.message.Message):
    """GetBulkPipelineTriggerPriceRequest represents a query for pipeline trigger
    prices in bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetPipelineTriggerPriceRequest]:
        """A list of pipeline trigger price request payloads"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetPipelineTriggerPriceRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkPipelineTriggerPriceRequest = GetBulkPipelineTriggerPriceRequest

@typing_extensions.final
class GetBulkPipelineTriggerPriceResponse(google.protobuf.message.Message):
    """GetBulkPipelineTriggerPriceResponse represents a response to
    GetBulkPipelineTriggerPriceRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_PRICES_FIELD_NUMBER: builtins.int
    @property
    def bulk_prices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetPipelineTriggerPriceResponse]:
        """A list of pipeline trigger price lists"""
    def __init__(
        self,
        *,
        bulk_prices: collections.abc.Iterable[global___GetPipelineTriggerPriceResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_prices", b"bulk_prices"]) -> None: ...

global___GetBulkPipelineTriggerPriceResponse = GetBulkPipelineTriggerPriceResponse

@typing_extensions.final
class GetModelOnlinePriceRequest(google.protobuf.message.Message):
    """Query for model online price

    GetPipelineTriggerPriceRequest represents a query for price data of the
    billing periods covered by the time interval
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    TIME_INTERVAL_FIELD_NUMBER: builtins.int
    @property
    def user(self) -> global___UserData:
        """User information"""
    @property
    def model(self) -> global___ModelData:
        """Pipeline information"""
    @property
    def time_interval(self) -> global___TimeInterval:
        """Time interval"""
    def __init__(
        self,
        *,
        user: global___UserData | None = ...,
        model: global___ModelData | None = ...,
        time_interval: global___TimeInterval | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["model", b"model", "time_interval", b"time_interval", "user", b"user"]) -> None: ...

global___GetModelOnlinePriceRequest = GetModelOnlinePriceRequest

@typing_extensions.final
class GetModelOnlinePriceResponse(google.protobuf.message.Message):
    """GetModelOnlinePriceResponse represents a response to
    GetModelOnlinePriceRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PRICE_FIELD_NUMBER: builtins.int
    @property
    def price(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PriceData]:
        """A list of model online prices given the billing periods covered by the time
        interval
        """
    def __init__(
        self,
        *,
        price: collections.abc.Iterable[global___PriceData] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["price", b"price"]) -> None: ...

global___GetModelOnlinePriceResponse = GetModelOnlinePriceResponse

@typing_extensions.final
class GetBulkModelOnlinePriceRequest(google.protobuf.message.Message):
    """GetBulkModelOnlinePriceRequest represents a query for model online prices in
    bulk
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_QUERIES_FIELD_NUMBER: builtins.int
    @property
    def bulk_queries(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetModelOnlinePriceRequest]:
        """A list of model online price request payloads"""
    def __init__(
        self,
        *,
        bulk_queries: collections.abc.Iterable[global___GetModelOnlinePriceRequest] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_queries", b"bulk_queries"]) -> None: ...

global___GetBulkModelOnlinePriceRequest = GetBulkModelOnlinePriceRequest

@typing_extensions.final
class GetBulkModelOnlinePriceResponse(google.protobuf.message.Message):
    """GetBulkModelOnlinePriceResponse represents a response to
    GetBulkModelOnlinePriceRequest
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BULK_PRICES_FIELD_NUMBER: builtins.int
    @property
    def bulk_prices(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___GetModelOnlinePriceResponse]:
        """A list of model online price lists"""
    def __init__(
        self,
        *,
        bulk_prices: collections.abc.Iterable[global___GetModelOnlinePriceResponse] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bulk_prices", b"bulk_prices"]) -> None: ...

global___GetBulkModelOnlinePriceResponse = GetBulkModelOnlinePriceResponse

@typing_extensions.final
class NullMessage(google.protobuf.message.Message):
    """Nul Message for gRPC REQ/RES"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___NullMessage = NullMessage

@typing_extensions.final
class UserData(google.protobuf.message.Message):
    """Records for all usage reports

    User records definition
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """User unique id"""
    name: builtins.str
    """User name, which is not necessary for service queries"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "uid", b"uid"]) -> None: ...

global___UserData = UserData

@typing_extensions.final
class PipelineData(google.protobuf.message.Message):
    """Records for pipeline trigger reports and queries

    Pipeline records definition
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """Pipeline unique id that is auto generated"""
    id: builtins.str
    """Pipeline id assigned by users"""
    task: builtins.str
    """Pipeline task indicate the AI task this pipeline supports"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        task: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "task", b"task", "uid", b"uid"]) -> None: ...

global___PipelineData = PipelineData

@typing_extensions.final
class PipelineUsageRecord(google.protobuf.message.Message):
    """Pipeline trigger usage record definition"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REQUEST_ID_FIELD_NUMBER: builtins.int
    OPERATION_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TRIGGER_TIME_FIELD_NUMBER: builtins.int
    RECORD_TIME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    request_id: builtins.str
    """A unique request id given by vdp when trigger the pipeline."""
    operation_id: builtins.str
    """A unique operation id given by vdp"""
    status: builtins.str
    """The HTTP status received when user trigger the pipeline"""
    @property
    def trigger_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the pipeline is triggered"""
    @property
    def record_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the pipeline trigger usage is recorded"""
    value: builtins.int
    """The pipeline trigger usage record. The unit of the usage should be
    consistent with Stripe
    """
    def __init__(
        self,
        *,
        request_id: builtins.str = ...,
        operation_id: builtins.str = ...,
        status: builtins.str = ...,
        trigger_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        record_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["record_time", b"record_time", "trigger_time", b"trigger_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operation_id", b"operation_id", "record_time", b"record_time", "request_id", b"request_id", "status", b"status", "trigger_time", b"trigger_time", "value", b"value"]) -> None: ...

global___PipelineUsageRecord = PipelineUsageRecord

@typing_extensions.final
class ModelData(google.protobuf.message.Message):
    """Records for model online reports and queries

    Pipeline records definition
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INSTANCE_ID_FIELD_NUMBER: builtins.int
    TASK_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """Model unique id that is auto generated"""
    id: builtins.str
    """Model id that is given by the users"""
    instance_id: builtins.str
    """The id of the model instance that is deployed"""
    task: builtins.str
    """The AI task supported by this model"""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        instance_id: builtins.str = ...,
        task: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "instance_id", b"instance_id", "task", b"task", "uid", b"uid"]) -> None: ...

global___ModelData = ModelData

@typing_extensions.final
class ModelUsageRecord(google.protobuf.message.Message):
    """Model online usage record definition"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPLOY_TIME_FIELD_NUMBER: builtins.int
    RECORD_TIME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def deploy_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the model is ONLINE"""
    @property
    def record_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when model online usage is recorded"""
    value: builtins.int
    """The model online usage record that is logged in cumulative manner. This
    value records the cumulative usage since model is online in the current
    billing period
    """
    def __init__(
        self,
        *,
        deploy_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        record_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["deploy_time", b"deploy_time", "record_time", b"record_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deploy_time", b"deploy_time", "record_time", b"record_time", "value", b"value"]) -> None: ...

global___ModelUsageRecord = ModelUsageRecord

@typing_extensions.final
class UsageSummary(google.protobuf.message.Message):
    """Record for query response

    Usage summary definition
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the summary is generated"""
    value: builtins.int
    """The total usage since the beginning of the current billing period"""
    def __init__(
        self,
        *,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        value: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["time", b"time", "value", b"value"]) -> None: ...

global___UsageSummary = UsageSummary

@typing_extensions.final
class PriceData(google.protobuf.message.Message):
    """Pricing information"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIME_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    @property
    def time(self) -> global___TimeInterval:
        """Time when the price record is generated"""
    currency: builtins.str
    """The currency of the price"""
    amount: builtins.float
    """The price of the query usage in the current billing period"""
    def __init__(
        self,
        *,
        time: global___TimeInterval | None = ...,
        currency: builtins.str = ...,
        amount: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount", b"amount", "currency", b"currency", "time", b"time"]) -> None: ...

global___PriceData = PriceData

@typing_extensions.final
class TimeInterval(google.protobuf.message.Message):
    """Arguments for query

    Time interval
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start time of the interval"""
    @property
    def end_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """End time of the interval"""
    def __init__(
        self,
        *,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        end_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> None: ...

global___TimeInterval = TimeInterval



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import common.healthcheck.v1beta.healthcheck_pb2
import common.run.v1alpha.run_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FileProcessStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileProcessStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileProcessStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FILE_PROCESS_STATUS_UNSPECIFIED: _FileProcessStatus.ValueType  # 0
    """UNSPECIFIED"""
    FILE_PROCESS_STATUS_NOTSTARTED: _FileProcessStatus.ValueType  # 1
    """NOTSTARTED"""
    FILE_PROCESS_STATUS_WAITING: _FileProcessStatus.ValueType  # 2
    """file is waiting for embedding process"""
    FILE_PROCESS_STATUS_CONVERTING: _FileProcessStatus.ValueType  # 3
    """file is converting"""
    FILE_PROCESS_STATUS_CHUNKING: _FileProcessStatus.ValueType  # 4
    """file is chunking"""
    FILE_PROCESS_STATUS_EMBEDDING: _FileProcessStatus.ValueType  # 5
    """file is embedding"""
    FILE_PROCESS_STATUS_COMPLETED: _FileProcessStatus.ValueType  # 6
    """completed"""
    FILE_PROCESS_STATUS_FAILED: _FileProcessStatus.ValueType  # 7
    """failed"""

class FileProcessStatus(_FileProcessStatus, metaclass=_FileProcessStatusEnumTypeWrapper):
    """file embedding process status"""

FILE_PROCESS_STATUS_UNSPECIFIED: FileProcessStatus.ValueType  # 0
"""UNSPECIFIED"""
FILE_PROCESS_STATUS_NOTSTARTED: FileProcessStatus.ValueType  # 1
"""NOTSTARTED"""
FILE_PROCESS_STATUS_WAITING: FileProcessStatus.ValueType  # 2
"""file is waiting for embedding process"""
FILE_PROCESS_STATUS_CONVERTING: FileProcessStatus.ValueType  # 3
"""file is converting"""
FILE_PROCESS_STATUS_CHUNKING: FileProcessStatus.ValueType  # 4
"""file is chunking"""
FILE_PROCESS_STATUS_EMBEDDING: FileProcessStatus.ValueType  # 5
"""file is embedding"""
FILE_PROCESS_STATUS_COMPLETED: FileProcessStatus.ValueType  # 6
"""completed"""
FILE_PROCESS_STATUS_FAILED: FileProcessStatus.ValueType  # 7
"""failed"""
global___FileProcessStatus = FileProcessStatus

class _FileType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FileTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FileType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    FILE_TYPE_UNSPECIFIED: _FileType.ValueType  # 0
    """unspecified"""
    FILE_TYPE_TEXT: _FileType.ValueType  # 1
    """text"""
    FILE_TYPE_PDF: _FileType.ValueType  # 2
    """PDF"""
    FILE_TYPE_MARKDOWN: _FileType.ValueType  # 3
    """MARKDOWN"""
    FILE_TYPE_PNG: _FileType.ValueType  # 4
    """PNG(not supported yet)"""
    FILE_TYPE_JPEG: _FileType.ValueType  # 5
    """JPEG(not supported yet)"""
    FILE_TYPE_JPG: _FileType.ValueType  # 6
    """JPG(not supported yet)"""
    FILE_TYPE_HTML: _FileType.ValueType  # 7
    """HTML"""
    FILE_TYPE_DOCX: _FileType.ValueType  # 8
    """DOCX"""
    FILE_TYPE_DOC: _FileType.ValueType  # 9
    """DOC"""
    FILE_TYPE_PPT: _FileType.ValueType  # 10
    """PPT"""
    FILE_TYPE_PPTX: _FileType.ValueType  # 11
    """PPTX"""
    FILE_TYPE_XLS: _FileType.ValueType  # 12
    """XLS"""
    FILE_TYPE_XLSX: _FileType.ValueType  # 13
    """XLSX"""
    FILE_TYPE_CSV: _FileType.ValueType  # 14
    """CSV"""

class FileType(_FileType, metaclass=_FileTypeEnumTypeWrapper):
    """file type"""

FILE_TYPE_UNSPECIFIED: FileType.ValueType  # 0
"""unspecified"""
FILE_TYPE_TEXT: FileType.ValueType  # 1
"""text"""
FILE_TYPE_PDF: FileType.ValueType  # 2
"""PDF"""
FILE_TYPE_MARKDOWN: FileType.ValueType  # 3
"""MARKDOWN"""
FILE_TYPE_PNG: FileType.ValueType  # 4
"""PNG(not supported yet)"""
FILE_TYPE_JPEG: FileType.ValueType  # 5
"""JPEG(not supported yet)"""
FILE_TYPE_JPG: FileType.ValueType  # 6
"""JPG(not supported yet)"""
FILE_TYPE_HTML: FileType.ValueType  # 7
"""HTML"""
FILE_TYPE_DOCX: FileType.ValueType  # 8
"""DOCX"""
FILE_TYPE_DOC: FileType.ValueType  # 9
"""DOC"""
FILE_TYPE_PPT: FileType.ValueType  # 10
"""PPT"""
FILE_TYPE_PPTX: FileType.ValueType  # 11
"""PPTX"""
FILE_TYPE_XLS: FileType.ValueType  # 12
"""XLS"""
FILE_TYPE_XLSX: FileType.ValueType  # 13
"""XLSX"""
FILE_TYPE_CSV: FileType.ValueType  # 14
"""CSV"""
global___FileType = FileType

class _CatalogRunAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CatalogRunActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CatalogRunAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CATALOG_RUN_ACTION_UNSPECIFIED: _CatalogRunAction.ValueType  # 0
    """Unspecified."""
    CATALOG_RUN_ACTION_CREATE: _CatalogRunAction.ValueType  # 1
    """Create catalog."""
    CATALOG_RUN_ACTION_UPDATE: _CatalogRunAction.ValueType  # 2
    """Update catalog."""
    CATALOG_RUN_ACTION_DELETE: _CatalogRunAction.ValueType  # 3
    """Delete catalog."""
    CATALOG_RUN_ACTION_CREATE_FILE: _CatalogRunAction.ValueType  # 4
    """Upload catalog file."""
    CATALOG_RUN_ACTION_PROCESS_FILE: _CatalogRunAction.ValueType  # 5
    """Process catalog file."""
    CATALOG_RUN_ACTION_DELETE_FILE: _CatalogRunAction.ValueType  # 6
    """Delete catalog file."""

class CatalogRunAction(_CatalogRunAction, metaclass=_CatalogRunActionEnumTypeWrapper):
    """CatalogRunAction describes the actions a user has over a catalog."""

CATALOG_RUN_ACTION_UNSPECIFIED: CatalogRunAction.ValueType  # 0
"""Unspecified."""
CATALOG_RUN_ACTION_CREATE: CatalogRunAction.ValueType  # 1
"""Create catalog."""
CATALOG_RUN_ACTION_UPDATE: CatalogRunAction.ValueType  # 2
"""Update catalog."""
CATALOG_RUN_ACTION_DELETE: CatalogRunAction.ValueType  # 3
"""Delete catalog."""
CATALOG_RUN_ACTION_CREATE_FILE: CatalogRunAction.ValueType  # 4
"""Upload catalog file."""
CATALOG_RUN_ACTION_PROCESS_FILE: CatalogRunAction.ValueType  # 5
"""Process catalog file."""
CATALOG_RUN_ACTION_DELETE_FILE: CatalogRunAction.ValueType  # 6
"""Delete catalog file."""
global___CatalogRunAction = CatalogRunAction

@typing_extensions.final
class LivenessRequest(google.protobuf.message.Message):
    """LivenessRequest represents a request to check a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___LivenessRequest = LivenessRequest

@typing_extensions.final
class LivenessResponse(google.protobuf.message.Message):
    """LivenessResponse represents a response for a service liveness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___LivenessResponse = LivenessResponse

@typing_extensions.final
class ReadinessRequest(google.protobuf.message.Message):
    """ReadinessRequest represents a request to check a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_REQUEST_FIELD_NUMBER: builtins.int
    @property
    def health_check_request(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest:
        """HealthCheckRequest message"""
    def __init__(
        self,
        *,
        health_check_request: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckRequest | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_health_check_request", b"_health_check_request", "health_check_request", b"health_check_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_health_check_request", b"_health_check_request"]) -> typing_extensions.Literal["health_check_request"] | None: ...

global___ReadinessRequest = ReadinessRequest

@typing_extensions.final
class ReadinessResponse(google.protobuf.message.Message):
    """ReadinessResponse represents a response for a service readiness status"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HEALTH_CHECK_RESPONSE_FIELD_NUMBER: builtins.int
    @property
    def health_check_response(self) -> common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse:
        """HealthCheckResponse message"""
    def __init__(
        self,
        *,
        health_check_response: common.healthcheck.v1beta.healthcheck_pb2.HealthCheckResponse | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["health_check_response", b"health_check_response"]) -> None: ...

global___ReadinessResponse = ReadinessResponse

@typing_extensions.final
class RepositoryTag(google.protobuf.message.Message):
    """

    This API is under development and, therefore, some of its entities and
    endpoints are not implemented yet. This section aims to give context about the
    current interface and how it fits in the Artifact vision.

    # Artifact

    The Artifact domain is responsible of storing data that will later be used for
    processing unstructured data. Artifact will support the following types of
    data:

    - Repositories
    - Objects
    - Vectors

    ## Repositories

    An implementation of the [OCI Distribution Specification](https://github.com/opencontainers/distribution-spec?tab=readme-ov-file)
    is used to manage versioned content. The main use for repositories is storing
    container images that can be used to deploy AI models or VDP pipelines.

    The ID of a repository has 2 segments, the owner (an Instill user or
    organization) and the content ID (the AI model or pipeline ID), e.g.
    `curious-wombat/llava-34b`.

    ## Objects

    Raw data is stored in binary blobs. Object storage allows users to upload data
    (e.g. images, audio) that can be used by pipelines or to store the results or a
    pipeline trigger.

    ## Vectors

    Vector embeddings have their own storage, which allows fast retrieval and similarity search.

    RepositoryTag contains information about the version of some content in a
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    DIGEST_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the tag, defined by its parent repository and ID.
    - Format: `repositories/{repository.id}/tags/{tag.id}`.
    """
    id: builtins.str
    """The tag identifier."""
    digest: builtins.str
    """The Artifact backend will register the tag digest and timestamp when a
    new version is pushed. However, the registry remains the source of truth
    for tags, so if this information isn't found in the Artifact database,
    these fields will be empty.

    Unique identifier, computed from the manifest the tag refers to.
    """
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Tag update time, i.e. timestamp of the last push."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        id: builtins.str = ...,
        digest: builtins.str = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["digest", b"digest", "id", b"id", "name", b"name", "update_time", b"update_time"]) -> None: ...

global___RepositoryTag = RepositoryTag

@typing_extensions.final
class ListRepositoryTagsRequest(google.protobuf.message.Message):
    """ListRepositoryTagsRequest represents a request to list the tags of a
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of tags to return. The default and cap values are 10
    and 100, respectively.
    """
    page: builtins.int
    """Page number."""
    parent: builtins.str
    """The repository holding the different versions of a given content.
    - Format: `repositories/{repository.id}`.
    - Example: `repositories/flaming-wombat/llama-2-7b`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page: builtins.int | None = ...,
        parent: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_page", b"_page", "_page_size", b"_page_size", "page", b"page", "page_size", b"page_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_page", b"_page", "_page_size", b"_page_size", "page", b"page", "page_size", b"page_size", "parent", b"parent"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page", b"_page"]) -> typing_extensions.Literal["page"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...

global___ListRepositoryTagsRequest = ListRepositoryTagsRequest

@typing_extensions.final
class ListRepositoryTagsResponse(google.protobuf.message.Message):
    """ListRepositoryTagsResponse contains a list of container image tags."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAGS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RepositoryTag]:
        """A list of repository tags."""
    total_size: builtins.int
    """Total number of tags."""
    page_size: builtins.int
    """The requested page size."""
    page: builtins.int
    """The requested page offset."""
    def __init__(
        self,
        *,
        tags: collections.abc.Iterable[global___RepositoryTag] | None = ...,
        total_size: builtins.int = ...,
        page_size: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page", b"page", "page_size", b"page_size", "tags", b"tags", "total_size", b"total_size"]) -> None: ...

global___ListRepositoryTagsResponse = ListRepositoryTagsResponse

@typing_extensions.final
class CreateRepositoryTagRequest(google.protobuf.message.Message):
    """CreateRepositoryTagRequest represents a request to add a tag to a given
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> global___RepositoryTag:
        """The tag information."""
    def __init__(
        self,
        *,
        tag: global___RepositoryTag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___CreateRepositoryTagRequest = CreateRepositoryTagRequest

@typing_extensions.final
class CreateRepositoryTagResponse(google.protobuf.message.Message):
    """CreateRepositoryTagResponse contains the created tag."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> global___RepositoryTag:
        """The created tag."""
    def __init__(
        self,
        *,
        tag: global___RepositoryTag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___CreateRepositoryTagResponse = CreateRepositoryTagResponse

@typing_extensions.final
class GetRepositoryTagRequest(google.protobuf.message.Message):
    """GetRepositoryTagRequest represents a request to add a tag to a given
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the tag, defined by its parent repository and ID.
    - Format: `repositories/{repository.id}/tags/{tag.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___GetRepositoryTagRequest = GetRepositoryTagRequest

@typing_extensions.final
class GetRepositoryTagResponse(google.protobuf.message.Message):
    """GetRepositoryTagResponse contains the created tag."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TAG_FIELD_NUMBER: builtins.int
    @property
    def tag(self) -> global___RepositoryTag:
        """The created tag."""
    def __init__(
        self,
        *,
        tag: global___RepositoryTag | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["tag", b"tag"]) -> None: ...

global___GetRepositoryTagResponse = GetRepositoryTagResponse

@typing_extensions.final
class DeleteRepositoryTagRequest(google.protobuf.message.Message):
    """DeleteRepositoryTagRequest represents a request to delete a tag to a given
    repository.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the tag, defined by its parent repository and ID.
    - Format: `repositories/{repository.id}/tags/{tag.id}`.
    """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeleteRepositoryTagRequest = DeleteRepositoryTagRequest

@typing_extensions.final
class DeleteRepositoryTagResponse(google.protobuf.message.Message):
    """DeleteRepositoryTagResponse represent an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteRepositoryTagResponse = DeleteRepositoryTagResponse

@typing_extensions.final
class Catalog(google.protobuf.message.Message):
    """Catalog represents a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_UID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    OWNER_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    CONVERTING_PIPELINES_FIELD_NUMBER: builtins.int
    SPLITTING_PIPELINES_FIELD_NUMBER: builtins.int
    EMBEDDING_PIPELINES_FIELD_NUMBER: builtins.int
    DOWNSTREAM_APPS_FIELD_NUMBER: builtins.int
    TOTAL_FILES_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    USED_STORAGE_FIELD_NUMBER: builtins.int
    catalog_uid: builtins.str
    """The catalog uid."""
    catalog_id: builtins.str
    """The catalog id."""
    name: builtins.str
    """The catalog name."""
    description: builtins.str
    """The catalog description."""
    create_time: builtins.str
    """The creation time of the catalog."""
    update_time: builtins.str
    """The last update time of the catalog."""
    owner_name: builtins.str
    """The owner/namespace of the catalog."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The catalog tags."""
    @property
    def converting_pipelines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The catalog converting pipelines."""
    @property
    def splitting_pipelines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The catalog splitting pipelines."""
    @property
    def embedding_pipelines(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The catalog embedding pipelines."""
    @property
    def downstream_apps(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The downstream apps"""
    total_files: builtins.int
    """The total files in catalog."""
    total_tokens: builtins.int
    """The total tokens in catalog."""
    used_storage: builtins.int
    """The current used storage in catalog."""
    def __init__(
        self,
        *,
        catalog_uid: builtins.str = ...,
        catalog_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        create_time: builtins.str = ...,
        update_time: builtins.str = ...,
        owner_name: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        converting_pipelines: collections.abc.Iterable[builtins.str] | None = ...,
        splitting_pipelines: collections.abc.Iterable[builtins.str] | None = ...,
        embedding_pipelines: collections.abc.Iterable[builtins.str] | None = ...,
        downstream_apps: collections.abc.Iterable[builtins.str] | None = ...,
        total_files: builtins.int = ...,
        total_tokens: builtins.int = ...,
        used_storage: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "catalog_uid", b"catalog_uid", "converting_pipelines", b"converting_pipelines", "create_time", b"create_time", "description", b"description", "downstream_apps", b"downstream_apps", "embedding_pipelines", b"embedding_pipelines", "name", b"name", "owner_name", b"owner_name", "splitting_pipelines", b"splitting_pipelines", "tags", b"tags", "total_files", b"total_files", "total_tokens", b"total_tokens", "update_time", b"update_time", "used_storage", b"used_storage"]) -> None: ...

global___Catalog = Catalog

@typing_extensions.final
class CreateCatalogRequest(google.protobuf.message.Message):
    """CreateCatalogRequest represents a request to create a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The catalog's owner(namespaces)."""
    name: builtins.str
    """The catalog name."""
    description: builtins.str
    """The catalog description."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The catalog tags."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "name", b"name", "namespace_id", b"namespace_id", "tags", b"tags"]) -> None: ...

global___CreateCatalogRequest = CreateCatalogRequest

@typing_extensions.final
class CreateCatalogResponse(google.protobuf.message.Message):
    """CreateCatalogResponse represents a response for creating a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_FIELD_NUMBER: builtins.int
    @property
    def catalog(self) -> global___Catalog:
        """The created catalog."""
    def __init__(
        self,
        *,
        catalog: global___Catalog | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["catalog", b"catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog", b"catalog"]) -> None: ...

global___CreateCatalogResponse = CreateCatalogResponse

@typing_extensions.final
class ListCatalogsRequest(google.protobuf.message.Message):
    """Request message for ListCatalogs"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """User ID for which to list the catalogs"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace_id", b"namespace_id"]) -> None: ...

global___ListCatalogsRequest = ListCatalogsRequest

@typing_extensions.final
class ListCatalogsResponse(google.protobuf.message.Message):
    """GetCatalogsResponse represents a response for getting all catalogs from users."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOGS_FIELD_NUMBER: builtins.int
    @property
    def catalogs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Catalog]:
        """The catalogs container."""
    def __init__(
        self,
        *,
        catalogs: collections.abc.Iterable[global___Catalog] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalogs", b"catalogs"]) -> None: ...

global___ListCatalogsResponse = ListCatalogsResponse

@typing_extensions.final
class UpdateCatalogRequest(google.protobuf.message.Message):
    """UpdateCatalogRequest represents a request to update a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    catalog_id: builtins.str
    """The catalog id."""
    description: builtins.str
    """The catalog description."""
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The catalog tags."""
    namespace_id: builtins.str
    """The catalog owner(namespace)."""
    def __init__(
        self,
        *,
        catalog_id: builtins.str = ...,
        description: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        namespace_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "description", b"description", "namespace_id", b"namespace_id", "tags", b"tags"]) -> None: ...

global___UpdateCatalogRequest = UpdateCatalogRequest

@typing_extensions.final
class UpdateCatalogResponse(google.protobuf.message.Message):
    """UpdateCatalogResponse represents a response for updating a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_FIELD_NUMBER: builtins.int
    @property
    def catalog(self) -> global___Catalog:
        """The updated catalog."""
    def __init__(
        self,
        *,
        catalog: global___Catalog | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["catalog", b"catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog", b"catalog"]) -> None: ...

global___UpdateCatalogResponse = UpdateCatalogResponse

@typing_extensions.final
class DeleteCatalogRequest(google.protobuf.message.Message):
    """DeleteCatalogRequest represents a request to delete a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The owner's id. i.e. namespace."""
    catalog_id: builtins.str
    """The catalog id."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteCatalogRequest = DeleteCatalogRequest

@typing_extensions.final
class DeleteCatalogResponse(google.protobuf.message.Message):
    """DeleteCatalogResponse represents a response for deleting a catalog."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_FIELD_NUMBER: builtins.int
    @property
    def catalog(self) -> global___Catalog:
        """The catalog identifier."""
    def __init__(
        self,
        *,
        catalog: global___Catalog | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["catalog", b"catalog"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog", b"catalog"]) -> None: ...

global___DeleteCatalogResponse = DeleteCatalogResponse

@typing_extensions.final
class File(google.protobuf.message.Message):
    """file"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    PROCESS_STATUS_FIELD_NUMBER: builtins.int
    PROCESS_OUTCOME_FIELD_NUMBER: builtins.int
    RETRIEVABLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    OWNER_UID_FIELD_NUMBER: builtins.int
    CREATOR_UID_FIELD_NUMBER: builtins.int
    CATALOG_UID_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    DELETE_TIME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TOTAL_CHUNKS_FIELD_NUMBER: builtins.int
    TOTAL_TOKENS_FIELD_NUMBER: builtins.int
    file_uid: builtins.str
    """file uid"""
    name: builtins.str
    """file name"""
    type: global___FileType.ValueType
    """file type"""
    process_status: global___FileProcessStatus.ValueType
    """file process status"""
    process_outcome: builtins.str
    """file process message"""
    retrievable: builtins.bool
    """retrievable(this is reserved for future use)"""
    content: builtins.str
    """content(this is reserved for future use)"""
    owner_uid: builtins.str
    """owner/namespace uid"""
    creator_uid: builtins.str
    """creator uid from authn token"""
    catalog_uid: builtins.str
    """catalog uid"""
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """create time"""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """update time"""
    @property
    def delete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """delete time"""
    size: builtins.int
    """file size in bytes"""
    total_chunks: builtins.int
    """total chunks"""
    total_tokens: builtins.int
    """total tokens"""
    def __init__(
        self,
        *,
        file_uid: builtins.str = ...,
        name: builtins.str = ...,
        type: global___FileType.ValueType = ...,
        process_status: global___FileProcessStatus.ValueType = ...,
        process_outcome: builtins.str = ...,
        retrievable: builtins.bool = ...,
        content: builtins.str = ...,
        owner_uid: builtins.str = ...,
        creator_uid: builtins.str = ...,
        catalog_uid: builtins.str = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        delete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        size: builtins.int = ...,
        total_chunks: builtins.int = ...,
        total_tokens: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "delete_time", b"delete_time", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_uid", b"catalog_uid", "content", b"content", "create_time", b"create_time", "creator_uid", b"creator_uid", "delete_time", b"delete_time", "file_uid", b"file_uid", "name", b"name", "owner_uid", b"owner_uid", "process_outcome", b"process_outcome", "process_status", b"process_status", "retrievable", b"retrievable", "size", b"size", "total_chunks", b"total_chunks", "total_tokens", b"total_tokens", "type", b"type", "update_time", b"update_time"]) -> None: ...

global___File = File

@typing_extensions.final
class UploadCatalogFileRequest(google.protobuf.message.Message):
    """upload file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    FILE_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """owner/namespace uid"""
    catalog_id: builtins.str
    """catalog id"""
    @property
    def file(self) -> global___File:
        """file"""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        file: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "file", b"file", "namespace_id", b"namespace_id"]) -> None: ...

global___UploadCatalogFileRequest = UploadCatalogFileRequest

@typing_extensions.final
class UploadCatalogFileResponse(google.protobuf.message.Message):
    """upload file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_FIELD_NUMBER: builtins.int
    @property
    def file(self) -> global___File:
        """file"""
    def __init__(
        self,
        *,
        file: global___File | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["file", b"file"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["file", b"file"]) -> None: ...

global___UploadCatalogFileResponse = UploadCatalogFileResponse

@typing_extensions.final
class DeleteCatalogFileRequest(google.protobuf.message.Message):
    """delete file request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UID_FIELD_NUMBER: builtins.int
    file_uid: builtins.str
    """The file uid."""
    def __init__(
        self,
        *,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uid", b"file_uid"]) -> None: ...

global___DeleteCatalogFileRequest = DeleteCatalogFileRequest

@typing_extensions.final
class DeleteCatalogFileResponse(google.protobuf.message.Message):
    """delete file response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UID_FIELD_NUMBER: builtins.int
    file_uid: builtins.str
    """The file uid."""
    def __init__(
        self,
        *,
        file_uid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uid", b"file_uid"]) -> None: ...

global___DeleteCatalogFileResponse = DeleteCatalogFileResponse

@typing_extensions.final
class ProcessCatalogFilesRequest(google.protobuf.message.Message):
    """Process Catalog File Request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UIDS_FIELD_NUMBER: builtins.int
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The file uid."""
    def __init__(
        self,
        *,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uids", b"file_uids"]) -> None: ...

global___ProcessCatalogFilesRequest = ProcessCatalogFilesRequest

@typing_extensions.final
class ProcessCatalogFilesResponse(google.protobuf.message.Message):
    """Process Catalog File Response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """The file uid."""
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___File] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files"]) -> None: ...

global___ProcessCatalogFilesResponse = ProcessCatalogFilesResponse

@typing_extensions.final
class ListCatalogFilesFilter(google.protobuf.message.Message):
    """list file filter
    todo: support more parameters
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_UIDS_FIELD_NUMBER: builtins.int
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The file uids."""
    def __init__(
        self,
        *,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["file_uids", b"file_uids"]) -> None: ...

global___ListCatalogFilesFilter = ListCatalogFilesFilter

@typing_extensions.final
class ListCatalogFilesRequest(google.protobuf.message.Message):
    """list files request"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The owner/namespace uid id."""
    catalog_id: builtins.str
    """The catalog id."""
    page_size: builtins.int
    """The page size (default:10; max 100)."""
    page_token: builtins.str
    """The next page token(default from first file's token)."""
    @property
    def filter(self) -> global___ListCatalogFilesFilter:
        """The filter."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: global___ListCatalogFilesFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_id", b"catalog_id", "filter", b"filter", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListCatalogFilesRequest = ListCatalogFilesRequest

@typing_extensions.final
class ListCatalogFilesResponse(google.protobuf.message.Message):
    """list files response"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___File]:
        """The list of files."""
    total_size: builtins.int
    """The total number of files."""
    page_size: builtins.int
    """The requested page size."""
    next_page_token: builtins.str
    """next page token"""
    @property
    def filter(self) -> global___ListCatalogFilesFilter:
        """The filter."""
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[global___File] | None = ...,
        total_size: builtins.int = ...,
        page_size: builtins.int = ...,
        next_page_token: builtins.str = ...,
        filter: global___ListCatalogFilesFilter | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["files", b"files", "filter", b"filter", "next_page_token", b"next_page_token", "page_size", b"page_size", "total_size", b"total_size"]) -> None: ...

global___ListCatalogFilesResponse = ListCatalogFilesResponse

@typing_extensions.final
class CatalogRun(google.protobuf.message.Message):
    """CatalogRun represents a single execution of a catalog action."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    CATALOG_UID_FIELD_NUMBER: builtins.int
    FILE_UIDS_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TOTAL_DURATION_FIELD_NUMBER: builtins.int
    RUNNER_ID_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PAYLOAD_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    COMPLETE_TIME_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    CREDIT_AMOUNT_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """Unique identifier for each run."""
    catalog_uid: builtins.str
    """catalog uid"""
    @property
    def file_uids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """The file uids."""
    action: global___CatalogRunAction.ValueType
    """Action of the catalog run."""
    status: common.run.v1alpha.run_pb2.RunStatus.ValueType
    """Current status of the run."""
    source: common.run.v1alpha.run_pb2.RunSource.ValueType
    """Origin of the run."""
    total_duration: builtins.int
    """Time taken to complete the run in milliseconds."""
    runner_id: builtins.str
    """Runner ID. (User UID)"""
    namespace_id: builtins.str
    """Namespace ID."""
    @property
    def payload(self) -> google.protobuf.struct_pb2.Struct:
        """Run request payload."""
    @property
    def start_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the run started execution."""
    @property
    def complete_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the run completed."""
    error: builtins.str
    """Error message if the run failed."""
    credit_amount: builtins.float
    """Credits used of internal accounting metric."""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        catalog_uid: builtins.str = ...,
        file_uids: collections.abc.Iterable[builtins.str] | None = ...,
        action: global___CatalogRunAction.ValueType = ...,
        status: common.run.v1alpha.run_pb2.RunStatus.ValueType = ...,
        source: common.run.v1alpha.run_pb2.RunSource.ValueType = ...,
        total_duration: builtins.int | None = ...,
        runner_id: builtins.str | None = ...,
        namespace_id: builtins.str | None = ...,
        payload: google.protobuf.struct_pb2.Struct | None = ...,
        start_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        complete_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        error: builtins.str | None = ...,
        credit_amount: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_complete_time", b"_complete_time", "_credit_amount", b"_credit_amount", "_error", b"_error", "_namespace_id", b"_namespace_id", "_payload", b"_payload", "_runner_id", b"_runner_id", "_total_duration", b"_total_duration", "complete_time", b"complete_time", "credit_amount", b"credit_amount", "error", b"error", "namespace_id", b"namespace_id", "payload", b"payload", "runner_id", b"runner_id", "start_time", b"start_time", "total_duration", b"total_duration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_complete_time", b"_complete_time", "_credit_amount", b"_credit_amount", "_error", b"_error", "_namespace_id", b"_namespace_id", "_payload", b"_payload", "_runner_id", b"_runner_id", "_total_duration", b"_total_duration", "action", b"action", "catalog_uid", b"catalog_uid", "complete_time", b"complete_time", "credit_amount", b"credit_amount", "error", b"error", "file_uids", b"file_uids", "namespace_id", b"namespace_id", "payload", b"payload", "runner_id", b"runner_id", "source", b"source", "start_time", b"start_time", "status", b"status", "total_duration", b"total_duration", "uid", b"uid"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_complete_time", b"_complete_time"]) -> typing_extensions.Literal["complete_time"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_credit_amount", b"_credit_amount"]) -> typing_extensions.Literal["credit_amount"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_error", b"_error"]) -> typing_extensions.Literal["error"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_namespace_id", b"_namespace_id"]) -> typing_extensions.Literal["namespace_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_payload", b"_payload"]) -> typing_extensions.Literal["payload"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_runner_id", b"_runner_id"]) -> typing_extensions.Literal["runner_id"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_total_duration", b"_total_duration"]) -> typing_extensions.Literal["total_duration"] | None: ...

global___CatalogRun = CatalogRun

@typing_extensions.final
class ListCatalogRunsResponse(google.protobuf.message.Message):
    """ListCatalogRunsResponse is the response message for ListCatalogRuns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CATALOG_RUNS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    @property
    def catalog_runs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CatalogRun]:
        """The list of runs."""
    total_size: builtins.int
    """The total number of runs matching the request."""
    page: builtins.int
    """The current page number."""
    page_size: builtins.int
    """The number of items per page."""
    def __init__(
        self,
        *,
        catalog_runs: collections.abc.Iterable[global___CatalogRun] | None = ...,
        total_size: builtins.int = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["catalog_runs", b"catalog_runs", "page", b"page", "page_size", b"page_size", "total_size", b"total_size"]) -> None: ...

global___ListCatalogRunsResponse = ListCatalogRunsResponse

@typing_extensions.final
class ListCatalogRunsRequest(google.protobuf.message.Message):
    """ListCatalogRunsRequest is the request message for ListCatalogRuns."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CATALOG_ID_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """The ID of the owner of the catalog."""
    catalog_id: builtins.str
    """The ID of the catalog for which the runs will be listed."""
    page: builtins.int
    """The page number to retrieve."""
    page_size: builtins.int
    """The maximum number of items per page to return. The default and cap values
    are 10 and 100, respectively.
    """
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    order_by: builtins.str
    """Order by field, with options for ordering by `id`, `create_time` or `update_time`.
    Format: `order_by=id` or `order_by=create_time desc`, default is `asc`.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        catalog_id: builtins.str = ...,
        page: builtins.int = ...,
        page_size: builtins.int = ...,
        filter: builtins.str | None = ...,
        order_by: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "filter", b"filter", "order_by", b"order_by"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_order_by", b"_order_by", "catalog_id", b"catalog_id", "filter", b"filter", "namespace_id", b"namespace_id", "order_by", b"order_by", "page", b"page", "page_size", b"page_size"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_order_by", b"_order_by"]) -> typing_extensions.Literal["order_by"] | None: ...

global___ListCatalogRunsRequest = ListCatalogRunsRequest
